{-#LANGUAGE MultiParamTypeClasses #-}
module Text.Parcom.ByteString.Strict
where

import Prelude hiding (head, null, tail)
import Data.ByteString
import Data.Word8
import Text.Parcom.Stream
import Text.Parcom.Word8

instance Stream ByteString Word8 where
    peek = head
    atEnd = null
    consume = tail

instance Listish ByteString Word8 where
    toList = unpack
    fromList = pack
